---
name: Bug report
about: Report a bug or unexpected behavior
title: ''
labels: bug
assignees: ''
---

## Description
<!--
Provide a clear description of the issue.
-->

## Example
<!--
Include a short example that reproduces the issue, if applicable.
-->

## Expected behavior
<!--
Describe the expected behavior, if applicable.
-->

## Versions
 - OS [e.g. Ubuntu 20.04]:
 - DasCore Version [e.g. 0.0.5]:
 - Python Version [e.g. 3.10]:
